==> _private_chat-1.0.7.tar.gz: lib/constant.dart <==
const kNumberLimitMessages = 25;

//DB
const String kCollectionUSERS = "users";
const String kCollectionMESSAGES = "messages"; 
const String kCollectionCONVERSATIONS = "conversations";
const String kCollectionCONNECTIONSTATUS = "connections_status";
const String kCollectionCALLS = 'calls';
const String kCollectionCALLSTATES = 'call_states';

const String kCallStateCALLING = 'calling';
const String kCallStateCANCELLED = 'cancelled';
const String kCallStateREJECTED = 'rejected';
const String kCallStateENDED = 'ended';
const String kCallStatePICKED = 'picked';

const String kDbTIMESTAMP = 'timestamp';
const String kDbCONTENT = 'content';
const String kDbCONTENTURL = 'contentUrl';
const String kDbCONTENTFILEINFOS = 'contentFileInfos';
const String kDbFILEEXT = 'ext';
const String kDbFILEFILENAME = 'fileName';
const String kDbFILEMIME = 'mime';
const String kDbFILEDURATION = 'duration';
const String kDbFROM = 'from';
const String kDbCHATSTATUS = 'chatStatus';
const String kDbCHATID = 'chatId';
const String kDbMESSAGETYPE = 'messageType';
const String kDbLASTMESSAGETIME = 'lastMessageTime';
const String kDbSTATUS = 'status';
const String kDbPICKEDAT = 'pickedAt';
const String kDbENDAT = 'endAt';
const String kDbCALLINFO = 'callInfo';
const String kDbREACTIONS = 'reactions';
const String kDbISREPLY = 'isReply';
const String kDbISEDITTED = 'isEditted';
const String kDbREPLYDOC = 'replyDoc';
const String kDbCUSTOMDATA = 'customData';
const String kDbMEMBERS = 'members';
const String kDbMEMBERSFIREBASEID = 'membersFirebaseId';
const String kDbMEMBERSDETAIL = 'membersDetail';
const String kDbCONVERSATIONID = 'conversationId';
const String kDbCONVERSATIONTYPE = 'conversationType';
const String kDbSOLO = 'solo';
const String kDbGroup = 'group';
const String kDbUSERNAME = "username";
const String kDbTHUMBNAIL = 'thumbnail';
const String kDbGROUPNAME = 'groupName';
const String kDbENCRYPTKEY = 'encryptKey';
const String kDbPERSONAL = 'personal';
const String kDbPERSONALRECEIVED = 'personalReceived';
const String kDbCONVERSATION = 'conversation';
const String kDbMUTED = 'muted';
const String kDbBLOCKED = 'blocked';
const String kDbBODYNOTIF = 'bodyNotif'; 
const String kDbPLATFORMID = 'platformId';
const String kDbIsPro = 'isPro';
const String kDb = '';
// const String kDb = '';
// const String kDb = '';
// const String kDb = '';
// const String kDb = '';

==> _private_chat-1.0.8.tar.gz: lib/constant.dart <==
const kNumberLimitMessages = 25;

//DB
const String kCollectionUSERS = "users";
const String kCollectionMESSAGES = "messages"; 
const String kCollectionCONVERSATIONS = "conversations";
const String kCollectionCONNECTIONSTATUS = "connections_status";
const String kCollectionCALLS = 'calls';
const String kCollectionCALLSTATES = 'call_states';

const String kCallStateCALLING = 'calling';
const String kCallStateCANCELLED = 'cancelled';
const String kCallStateREJECTED = 'rejected';
const String kCallStateENDED = 'ended';
const String kCallStatePICKED = 'picked';

const String kDbTIMESTAMP = 'timestamp';
const String kDbCONTENT = 'content';
const String kDbCONTENTURL = 'contentUrl';
const String kDbCONTENTFILEINFOS = 'contentFileInfos';
const String kDbFILEEXT = 'ext';
const String kDbFILEFILENAME = 'fileName';
const String kDbFILEMIME = 'mime';
const String kDbFILEDURATION = 'duration';
const String kDbFROM = 'from';
const String kDbCHATSTATUS = 'chatStatus';
const String kDbCHATID = 'chatId';
const String kDbMESSAGETYPE = 'messageType';
const String kDbLASTMESSAGETIME = 'lastMessageTime';
const String kDbSTATUS = 'status';
const String kDbPICKEDAT = 'pickedAt';
const String kDbENDAT = 'endAt';
const String kDbCALLINFO = 'callInfo';
const String kDbREACTIONS = 'reactions';
const String kDbISREPLY = 'isReply';
const String kDbISEDITTED = 'isEditted';
const String kDbREPLYDOC = 'replyDoc';
const String kDbCUSTOMDATA = 'customData';
const String kDbMEMBERS = 'members';
const String kDbMEMBERSFIREBASEID = 'membersFirebaseId';
const String kDbMEMBERSDETAIL = 'membersDetail';
const String kDbCONVERSATIONID = 'conversationId';
const String kDbCONVERSATIONTYPE = 'conversationType';
const String kDbSOLO = 'solo';
const String kDbGroup = 'group';
const String kDbUSERNAME = "username";
const String kDbTHUMBNAIL = 'thumbnail';
const String kDbGROUPNAME = 'groupName';
const String kDbENCRYPTKEY = 'encryptKey';
const String kDbPERSONAL = 'personal';
const String kDbPERSONALRECEIVED = 'personalReceived';
const String kDbCONVERSATION = 'conversation';
const String kDbMUTED = 'muted';
const String kDbBLOCKED = 'blocked';
const String kDbBODYNOTIF = 'bodyNotif'; 
const String kDbPLATFORMID = 'platformId';
const String kDbIsPro = 'isPro';
const String kDbFavorite = 'favorite';
// const String kDb = '';
// const String kDb = '';
// const String kDb = '';
// const String kDb = '';
